@@ -1,3 +1,4 @@
+import functools
 from unittest import TestCase
 from unittest.mock import call, patch
 
@@ -6,6 +7,14 @@ from seleniumwire.server import MitmProxy
 
 class MitmProxyTest(TestCase):
 
+    base_options_update = functools.partial(
+        call,
+        ssl_insecure=True,
+        upstream_cert=False,
+        stream_websockets=True,
+        suppress_connection_errors=True,
+    )
+
     def test_creates_storage(self):
         proxy = MitmProxy('somehost', 12345, {
             'request_storage_base_dir': '/some/dir',
@@ -55,12 +64,7 @@ class MitmProxyTest(TestCase):
         })
 
         self.mock_options.return_value.update.assert_has_calls([
-            call(
-                ssl_insecure=True,
-                upstream_cert=False,
-                stream_websockets=True,
-                suppress_connection_errors=True,
-            ),
+            self.base_options_update(),
             call(
                 test='foobar'
             )
@@ -74,12 +78,7 @@ class MitmProxyTest(TestCase):
         })
 
         self.mock_options.return_value.update.assert_has_calls([
-            call(
-                ssl_insecure=True,
-                upstream_cert=False,
-                stream_websockets=True,
-                suppress_connection_errors=True,
-            ),
+            self.base_options_update(),
             call(
                 test='foobar',
                 confdir='/tmp/dir'
@@ -97,11 +96,7 @@ class MitmProxyTest(TestCase):
         })
 
         self.mock_options.return_value.update.assert_has_calls([
-            call(
-                ssl_insecure=True,
-                upstream_cert=False,
-                stream_websockets=True,
-                suppress_connection_errors=True,
+            self.base_options_update(
                 mode='upstream:https://proxyserver:8080'
             ),
             call()
@@ -116,11 +111,7 @@ class MitmProxyTest(TestCase):
         })
 
         self.mock_options.return_value.update.assert_has_calls([
-            call(
-                ssl_insecure=True,
-                upstream_cert=False,
-                stream_websockets=True,
-                suppress_connection_errors=True,
+            self.base_options_update(
                 mode='upstream:http://proxyserver:8080'
             ),
             call()
@@ -135,17 +126,29 @@ class MitmProxyTest(TestCase):
         })
 
         self.mock_options.return_value.update.assert_has_calls([
-            call(
-                ssl_insecure=True,
-                upstream_cert=False,
-                stream_websockets=True,
-                suppress_connection_errors=True,
+            self.base_options_update(
                 mode='upstream:https://proxyserver:8080',
                 upstream_auth='user:pass'
             ),
             call()
         ])
 
+    def test_upstream_proxy_auth_empty_pass(self):
+        MitmProxy('somehost', 12345, {
+            'request_storage_base_dir': '/some/dir',
+            'proxy': {
+                'https': 'https://user:@proxyserver:8080',
+            }
+        })
+
+        self.mock_options.return_value.update.assert_has_calls([
+            self.base_options_update(
+                mode='upstream:https://proxyserver:8080',
+                upstream_auth='user:'
+            ),
+            call()
+        ])
+
     def test_upstream_proxy_custom_auth(self):
         MitmProxy('somehost', 12345, {
             'request_storage_base_dir': '/some/dir',
@@ -156,11 +159,7 @@ class MitmProxyTest(TestCase):
         })
 
         self.mock_options.return_value.update.assert_has_calls([
-            call(
-                ssl_insecure=True,
-                upstream_cert=False,
-                stream_websockets=True,
-                suppress_connection_errors=True,
+            self.base_options_update(
                 mode='upstream:https://proxyserver:8080',
                 upstream_custom_auth='Bearer 12345'
             ),
@@ -193,7 +192,7 @@ class MitmProxyTest(TestCase):
         proxy.serve_forever()
 
         self.mock_asyncio.set_event_loop.assert_called_once_with(proxy._event_loop)
-        self.mock_master.return_value.run.assert_called_once_with()
+        self.mock_master.return_value.run_loop.assert_called_once_with(proxy._event_loop)
 
     def test_address(self):
         self.mock_proxy_server.return_value.address = ('somehost', 12345)
@@ -242,7 +241,7 @@ class MitmProxyTest(TestCase):
         self.mock_addons = patcher.start()
         self.addCleanup(patcher.stop)
 
-        patcher = patch('seleniumwire.server.MitmProxyRequestHandler')
+        patcher = patch('seleniumwire.server.InterceptRequestHandler')
         self.mock_handler = patcher.start()
         self.addCleanup(patcher.stop)
 
